@@ -38,9 +38,11 @@ def format_es_param_result(r, param_list, is_need_decrypt, is_need_es_score, rou
                         value = value.get(_key, None)
                 else:
                     pass
-            if result_dict.get(param_key) is None:
-                if value is not None:
-                    result_dict[param_key] = value
+            if key_arr:
+                _key = key_arr[-1]
+                if result_dict.get(_key) is None:
+                    if value is not None:
+                        result_dict[_key] = value
     else:
         result_dict = r["_source"]
     if is_need_decrypt:
